SQLObject Links
===============

.. contents::

If you have a link you'd like added to this page, please submit a `pull
requests at GitHub <https://github.com/sqlobject/sqlobject/pulls>`_ or a
bug report with the link and title at `bug tracker
<https://sourceforge.net/p/sqlobject/bugs/>`_.

Articles and Documentation
--------------------------

* `Connecting databases to Python with SQLObject
  <http://www.ibm.com/developerworks/library/os-pythonsqlo/index.html>`_;
  an article at DeveloperWorks.

* `DB migration using sqlobject-admin how-to
  <http://www.algorithm.co.il/blogs/index.php/programming/python/simple-sqlobject-db-migration-how-to/>`_.

* `Using raw SQL with SQLObject and keeping the object-y goodness
  <http://www.psychicorigami.com/2007/12/16/using-raw-sql-with-sqlobject-and-keeping-the-object-y-goodness/>`_.

* `Example of using SQLObject with web.py under mod_wsgi
  <https://github.com/RhubarbSin/example-sqlobject-webpy>`_.

Open Source Projects
--------------------

* `Catwalk <http://turbogears.org/1.0/docs/Catwalk.html>`_ is a
  web-based SQLObject browser and object editor (included in
  TurboGears 1.0).

* `Ultra Gleeper <http://www.crummy.com/software/UltraGleeper/>`_, a
  Recommendation Engine for Web Pages.

* `Guten <http://guten.sourceforge.net/>`_; an application for
  browsing, reading, and managing books from `Project Gutenberg
  <https://www.gutenberg.org/>`_.

.. image:: https://sourceforge.net/sflogo.php?group_id=74338&type=10
   :target: https://sourceforge.net/projects/sqlobject
   :class: noborder
   :align: center
   :height: 15
   :width: 80
   :alt: Get SQLObject at SourceForge.net. Fast, secure and Free Open Source software downloads
